@@ -1,5 +1,5 @@
 package Lab::Moose::Instrument::SCPI::Sense::Function;
-$Lab::Moose::Instrument::SCPI::Sense::Function::VERSION = '3.664';
+$Lab::Moose::Instrument::SCPI::Sense::Function::VERSION = '3.670';
 #ABSTRACT: Role for the SCPI SENSe:FUNCtion subsystem
 
 use Moose::Role;
@@ -11,7 +11,10 @@ use Carp;
 
 use namespace::autoclean;
 
+excludes 'Lab::Moose::Instrument::SCPI::Sense::Function::Concurrent';
 
+
+# Cache used by multiple functions in sense subsystem
 cache sense_function => ( getter => 'sense_function_query' );
 
 sub sense_function_query {
@@ -30,24 +33,6 @@ sub sense_function {
 }
 
 
-cache sense_function_concurrent => ( getter => 'sense_function_concurrent' );
-
-sub sense_function_concurrent_query {
-    my ( $self, $channel, %args ) = validated_channel_getter( \@_ );
-
-    my $value = $self->query( command => "SENS${channel}:FUNC:CONC?", %args );
-    return $self->cached_sense_function_concurrent($value);
-}
-
-sub sense_function_concurrent {
-    my ( $self, $channel, $value, %args ) = validated_channel_setter(
-        \@_,
-        value => { isa => 'Bool' }
-    );
-
-    $self->write( command => "SENS${channel}:FUNC:CONC $value", %args );
-    return $self->cached_sense_function_concurrent($value);
-}
 
 1;
 
@@ -63,7 +48,22 @@ Lab::Moose::Instrument::SCPI::Sense::Function - Role for the SCPI SENSe:FUNCtion
 
 =head1 VERSION
 
-version 3.664
+version 3.670
+
+=head1 DESCRIPTION
+
+This role is intended for instruments which support a single sense function.
+The command for setting the function must be SENS:FUNC $function.
+Instruments with concurrent sense shell use the Sense::Function:Concurrent
+role. 
+
+The set sense function is used by other SENSE: roles, like SENSE:NPLC. For
+example,
+
+ $source->sense_function(value => 'CURR');
+ $source->sense_nplc(value => 10);
+
+will set the integration time for current measurement to 10 power line cycles.
 
 =head1 METHODS
 
@@ -71,11 +71,7 @@ version 3.664
 
 =head2 sense_function
 
-Query/Set the function used by the instrument.
-
-=head2 sense_function_concurrent_query/sense_function_concurrent
-
-Set/Get concurrent property of sensor block. Allowed values: C<0> or C<1>.
+Query/Enable the sense function used by the instrument
 
 =head1 COPYRIGHT AND LICENSE
 
