@@ -1,5 +1,5 @@
 package Lab::Moose::Instrument::SCPI::Sense::NPLC;
-$Lab::Moose::Instrument::SCPI::Sense::NPLC::VERSION = '3.664';
+$Lab::Moose::Instrument::SCPI::Sense::NPLC::VERSION = '3.670';
 #ABSTRACT: Role for the SCPI SENSe:$function:NPLC subsystem
 
 use Moose::Role;
@@ -9,7 +9,7 @@ use Lab::Moose::Instrument qw/validated_getter validated_setter/;
 use namespace::autoclean;
 
 
-with 'Lab::Moose::Instrument::SCPI::Sense::Function';
+requires 'cached_sense_function';
 
 cache sense_nplc => ( getter => 'sense_nplc_query' );
 
@@ -49,7 +49,7 @@ Lab::Moose::Instrument::SCPI::Sense::NPLC - Role for the SCPI SENSe:$function:NP
 
 =head1 VERSION
 
-version 3.664
+version 3.670
 
 =head1 METHODS
 
